function [MG,KG] = FEM2DLagrangeP1(coord,elem)
%%%%% COMPUTING FINITE ELEMENT MATRICES
% coordinates by element
coordX = coord(:,1); coordY = coord(:,2);
X = coordX(elem); Y = coordY(elem);
% compute (double) triangle volume |B| = 2*vol(T)
detB = X(:,1).*Y(:,2) - X(:,2).*Y(:,1) - X(:,1).*Y(:,3) + ...
    X(:,3).*Y(:,1) + X(:,2).*Y(:,3) - X(:,3).*Y(:,2);
% (B^B^-t) = c_ij, where C = B^-1B^-t
c11 = ((Y(:,3) - Y(:,1)).^2 + (X(:,3) - X(:,1)).^2)./detB;
c21 = (((Y(:,3) - Y(:,1)).*(Y(:,1) - Y(:,2))) + ...
      ((X(:,2) - X(:,1)).*(X(:,1) - X(:,3))))./detB;
c22 = ((Y(:,2) - Y(:,1)).^2 + (X(:,2) - X(:,1)).^2)./detB;
% matrices in the reference triangle
K11 = .5*[1 -1 0;
         -1 1 0;
          0 0 0];
K22 = .5*[1 0 -1;
          0 0 0;
         -1 0 1];
K21 = .5*[1 0 -1;
         -1 0 1; 
          0 0 0];
M = [2 1 1;
    1 2 1;
    1 1 2]/24;
% local stiffness matrices K = [K_1;K_2;...;K_N]
K = kron(c11,K11) + kron(c22,K22) + kron(c21,K21 + K21');
% local mass matrices M = [M_1;M_2;...;M_N]
M = kron(detB,M);
%%% ASSEMBLING OF GLOBAL MATRICES
RDOF = kron(ones(1,3),reshape(elem.',[],1));    
CDOF = kron(elem.',ones(1,3)).';
KG = sparse(RDOF(:),CDOF(:),K(:));
MG = sparse(RDOF(:),CDOF(:),M(:));
end